package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallAppCompanyUser;

/**
 * app-公司人员Mapper接口
 *
 * @author ruoyi
 * @date 2024-06-27
 */
public interface MallAppCompanyUserMapper
{
    /**
     * 查询app-公司人员
     *
     * @param companyUserId app-公司人员主键
     * @return app-公司人员
     */
    public MallAppCompanyUser selectMallAppCompanyUserByCompanyUserId(Long companyUserId);

    /**
     * 查询app-公司人员列表
     *
     * @param mallAppCompanyUser app-公司人员
     * @return app-公司人员集合
     */
    public List<MallAppCompanyUser> selectMallAppCompanyUserList(MallAppCompanyUser mallAppCompanyUser);

    /**
     * 新增app-公司人员
     *
     * @param mallAppCompanyUser app-公司人员
     * @return 结果
     */
    public int insertMallAppCompanyUser(MallAppCompanyUser mallAppCompanyUser);

    /**
     * 修改app-公司人员
     *
     * @param mallAppCompanyUser app-公司人员
     * @return 结果
     */
    public int updateMallAppCompanyUser(MallAppCompanyUser mallAppCompanyUser);

    /**
     * 删除app-公司人员
     *
     * @param companyUserId app-公司人员主键
     * @return 结果
     */
    public int deleteMallAppCompanyUserByCompanyUserId(Long companyUserId);

    /**
     * 批量删除app-公司人员
     *
     * @param companyUserIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallAppCompanyUserByCompanyUserIds(Long[] companyUserIds);

    /**
     * 根据公司人员名称查询公司人员
     *
     * @param companyUserName 公司人员名称
     * @return 公司人员
     */
    public MallAppCompanyUser selectMallAppCompanyUserByCompanyUserName(String companyUserName);

    /**
     * 根据公司人员账号查询公司人员
     *
     * @param companyUserAccount 公司人员账号
     * @return 公司人员
     */
    public MallAppCompanyUser selectMallAppCompanyUserByCompanyUserAccount(String companyUserAccount);

    /**
     * 根据系统用户ID查询公司人员
     *
     * @param sysUserId 系统用户ID
     * @return 公司人员
     */
    public MallAppCompanyUser selectMallAppCompanyUserBySysUserId(Long sysUserId);

    /**
     * 分公司业务员列表
     *
     * @param mallAppCompanyUser app-公司人员
     * @return app-公司人员集合
     */
    public List<MallAppCompanyUser> selectMallSalesmanList(MallAppCompanyUser mallAppCompanyUser);
}
